Annotation class abstract

Represents a PDF annotation.

Inheritance
Implementers

Constructors

Annotation({required int pageNumber})
Creates a new instance of the Annotation class.

Properties

author ↔ String?
The author of the annotation.
getter/setter pair
color ↔ Color
The color of the Annotation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isLocked ↔ bool
The lock state of the Annotation.
getter/setter pair
name ↔ String?
The name of the annotation.
getter/setter pair
opacity ↔ double
The opacity of the Annotation.
getter/setter pair
pageNumber → int
The page number of the annotation.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ String?
The subject of the annotation.
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited