PdfTextFormField class

Represents the text form field.

Inheritance

Properties

children → List<PdfTextFormField>?
Gets the child items associated with this PdfTextFormField.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
Gets the name of the PdfFormField.
no setterinherited
pageNumber → int
Gets the page number of the PdfFormField.
no setterinherited
readOnly ↔ bool
Gets or sets a value indicating whether the PdfFormField is read-only.
getter/setter pairinherited-getteroverride-setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
Gets or sets the text of the PdfTextFormField.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited